==> nextcloud-14.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/cs.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "activated" : "aktivováno",
    "updated" : "aktualizováno",
    "mounted" : "připojeno (mount)",
    "deactivated" : "deaktivováno",
    "beforeCreate" : "předVytvořením",
    "created" : "vytvořen",
    "beforeUpdate" : "předAktualizací",
    "beforeDestroy" : "předZničením",
    "destroyed" : "zničeno",
    "beforeMount" : "předPřipojením",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Zde jsou vaše záložní kódy. Kódy si uložte a/nebo vytiskněte, protože už je nebude možné zobrazit znovu.",
    "Save backup codes" : "Uložit záložní kódy",
    "Print backup codes" : "Vytisknout záložní kódy",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Záložní kódy byly vytvořeny. Využito {used} z {total} kódů.",
    "Regenerate backup codes" : "Vytvořit nové záložní kódy",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Pokud necháte vytvořit nové záložní kódy, staré budou automaticky zneplatněny.",
    "Generate backup codes" : "Vytvořit záložní kódy",
    "An error occurred while generating your backup codes" : "Při pokusu o vytvoření záložních kódů nastala chyba.",
    "Nextcloud backup codes" : "Nextcloud záložní kódy",
    "You created two-factor backup codes for your account" : "Vytvořili jste záložní kódy dvoufázového ověření pro váš účet",
    "Second-factor backup codes" : "Dvoufázové záložní kódy",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Máte zapnuté dvouúrovňové ověřování ale zatím jste nenechali vytvořit záložní kódy. Určitě to udělejte pro případ ztráty přístupu k druhé fázi.",
    "Backup code" : "Záložní kód",
    "Use backup code" : "Použít záložní kód",
    "Two factor backup codes" : "Záložní kódy pro dvoufázové ověřování",
    "A two-factor auth backup codes provider" : "Poskytovatel záložních kódů pro dvoustupňové ověřování",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Použijte jeden ze svých záložních kódů které jste si uložili při nastavování dvoufázového ověřování.",
    "Submit" : "Odeslat",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Záložní kódy byly vytvořeny. {{used}} z {{total}} kódů bylo využito."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/cs.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Zde jsou vaše záložní kódy. Kódy si uložte a/nebo vytiskněte, protože už je nebude možné zobrazit znovu.",
    "Save backup codes" : "Uložit záložní kódy",
    "Print backup codes" : "Vytisknout záložní kódy",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Záložní kódy byly vytvořeny. Využito {used} z {total} kódů.",
    "Regenerate backup codes" : "Vytvořit nové záložní kódy",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Pokud necháte vytvořit nové záložní kódy, staré budou automaticky zneplatněny.",
    "Generate backup codes" : "Vytvořit záložní kódy",
    "An error occurred while generating your backup codes" : "Při pokusu o vytvoření záložních kódů nastala chyba.",
    "Nextcloud backup codes" : "Nextcloud záložní kódy",
    "You created two-factor backup codes for your account" : "Vytvořili jste záložní kódy dvoufázového ověření pro váš účet",
    "Second-factor backup codes" : "Dvoufázové záložní kódy",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Máte zapnuté dvouúrovňové ověřování ale zatím jste nenechali vytvořit záložní kódy. Určitě to udělejte pro případ ztráty přístupu k druhé fázi.",
    "Backup code" : "Záložní kód",
    "Use backup code" : "Použít záložní kód",
    "Two factor backup codes" : "Záložní kódy pro dvoufázové ověřování",
    "A two-factor auth backup codes provider" : "Poskytovatel záložních kódů pro dvoustupňové ověřování",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Použijte jeden ze svých záložních kódů které jste si uložili při nastavování dvoufázového ověřování.",
    "Submit" : "Odeslat",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Záložní kódy byly vytvořeny. {{used}} z {{total}} kódů bylo využito.",
    "activated" : "aktivováno",
    "updated" : "aktualizováno",
    "mounted" : "připojeno (mount)",
    "deactivated" : "deaktivováno",
    "beforeCreate" : "předVytvořením",
    "created" : "vytvořen",
    "beforeUpdate" : "předAktualizací",
    "beforeDestroy" : "předZničením",
    "destroyed" : "zničeno",
    "beforeMount" : "předPřipojením"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
